@@ -4,9 +4,9 @@ import java.util.LinkedList;
 import java.util.List;
 
 public final class OrFilter extends Filter {
-	
-	private final List<Filter> children = new LinkedList<Filter>();
-	
+
+	private final List<Filter> children = new LinkedList<>();
+
 	public OrFilter addChild(Filter child) {
 		if (child instanceof OrFilter)
 			children.addAll(((OrFilter) child).children);
@@ -19,7 +19,7 @@ public final class OrFilter extends Filter {
 	public void append(StringBuilder builder) {
 		if (children.isEmpty())
 			return;
-		
+
 		builder.append("(|");
 		for (Filter child : children) {
 			child.append(builder);
