@@ -1,9 +1,10 @@
 package aQute.libg.gzip;
 
-import java.io.*;
+import java.io.FileInputStream;
+import java.io.InputStream;
 
-import junit.framework.*;
-import aQute.lib.io.*;
+import aQute.lib.io.IO;
+import junit.framework.TestCase;
 
 public class TestGzipUtils extends TestCase {
 	public void testUnzipped() throws Exception {
@@ -27,4 +28,4 @@ public class TestGzipUtils extends TestCase {
 			fis.close();
 		}
 	}
-}
\ No newline at end of file
+}
