@@ -1,31 +1,34 @@
 package aQute.libg.tarjan;
 
-import java.util.*;
+import static org.assertj.core.api.Assertions.assertThat;
 
-import junit.framework.*;
-import aQute.lib.collections.*;
+import java.util.ArrayList;
+import java.util.Collection;
+
+import aQute.lib.collections.MultiMap;
+import junit.framework.TestCase;
 
 public class TestTarjan extends TestCase {
 
 	public void testTarjan() throws Exception {
-		MultiMap<String,String> g = mkGraph("A{BC}B{A}C{DE}D{C}E{D}");
+		MultiMap<String, String> g = mkGraph("A{BC}B{A}C{DE}D{C}E{D}");
 		System.err.println(g);
 
-		Collection< ? extends Collection<String>> scc = Tarjan.tarjan(g);
+		Collection<? extends Collection<String>> scc = Tarjan.tarjan(g);
 
 		assertEquals(2, scc.size());
 		for (Collection<String> set : scc) {
 			if (set.size() == 3)
-				assertEquals(new HashSet<String>(Arrays.asList("E", "C", "D")), set);
+				assertThat(set).containsExactlyInAnyOrder("E", "C", "D");
 			else if (set.size() == 2)
-				assertEquals(new HashSet<String>(Arrays.asList("B", "A")), set);
+				assertThat(set).containsExactlyInAnyOrder("B", "A");
 			else
 				fail();
 		}
 	}
 
-	private MultiMap<String,String> mkGraph(String string) {
-		MultiMap<String,String> map = new MultiMap<String,String>();
+	private MultiMap<String, String> mkGraph(String string) {
+		MultiMap<String, String> map = new MultiMap<>();
 
 		String key = null;
 
@@ -40,7 +43,7 @@ public class TestTarjan extends TestCase {
 				default :
 					if (key == null) {
 						key = c + "";
-						map.put(key, new ArrayList<String>());
+						map.put(key, new ArrayList<>());
 					} else
 						map.add(key, c + "");
 			}
