@@ -1,25 +1,26 @@
 package aQute.bnd.ant;
 
-import java.io.*;
+import java.io.File;
 
-import org.apache.tools.ant.*;
+import org.apache.tools.ant.BuildException;
 
-import aQute.bnd.build.*;
+import aQute.bnd.build.Workspace;
 
 public class PackageTask extends BaseTask {
 	String	runFilePath	= null;
 	File	output		= null;
-	boolean keep        = false;
+	boolean	keep		= false;
 
+	@SuppressWarnings("deprecation")
 	@Override
 	public void execute() throws BuildException {
 		if (output == null)
 			throw new BuildException("Output file must be specified");
 
 		try {
-			Workspace.getProject(getProject().getBaseDir()).export(runFilePath, keep, output);
-		}
-		catch (Exception e) {
+			Workspace.getProject(getProject().getBaseDir())
+				.export(runFilePath, keep, output);
+		} catch (Exception e) {
 			throw new BuildException(e);
 		}
 	}
