@@ -1,36 +1,36 @@
 package aQute.bnd.ant;
 
-import org.apache.tools.ant.*;
+import org.apache.tools.ant.BuildException;
 
-import aQute.bnd.build.*;
 import aQute.bnd.build.Project;
+import aQute.bnd.build.Workspace;
 
 /**
  * <p>
- * ANT task to release into a repository, equivalent to:
- * <code>&lt;bnd command="release"/&gt;</code>
+ * ANT task to release into a repository, equivalent to: <code>&lt;bnd
+ * command="release"/&gt;</code>
  * </p>
  * <p>
  * To release into the <em>default</em> repository (defined by
  * <code>-releaserepo</code> in <code>build.bnd</code>):
  * </p>
- * 
+ *
  * <pre>
- *    &lt;bndrelease/&gt;
+ *  &lt;bndrelease/&gt;
  * </pre>
  * <p>
  * To release into a specific named repository:
- * 
+ *
  * <pre>
- *    &lt;bndrelease releaserepo="My Repository"/&gt;
+ *  &lt;bndrelease releaserepo="My Repository"/&gt;
  * </pre>
- * 
+ *
  * @author Neil Bartlett
- * @see {@link BndTask} for setup instructions.
+ * @see BndTask for setup instructions.
  */
 public class ReleaseTask extends BaseTask {
 
-	String	releaseRepo	= null;
+	String releaseRepo = null;
 
 	@Override
 	public void execute() throws BuildException {
@@ -44,8 +44,7 @@ public class ReleaseTask extends BaseTask {
 
 			if (report(project))
 				throw new BuildException("Release failed");
-		}
-		catch (Exception e) {
+		} catch (Exception e) {
 			e.printStackTrace();
 			throw new BuildException(e);
 		}
