@@ -1,6 +1,11 @@
-package eclipse_1_3;
+package eclipse_1_6;
 
 public class ClassRef {
+	class Inner {
+	};
+	static {
+		System.out.println(Inner.class);
+	}
 	
 	public static void main() {
 		System.out.println(javax.swing.Box.class);
