@@ -4,7 +4,12 @@ package aQute.bnd.compatibility;
  * The kind of thing we scope
  */
 public enum Kind {
-	ROOT, CLASS, FIELD, CONSTRUCTOR, METHOD, UNKNOWN;
+	ROOT,
+	CLASS,
+	FIELD,
+	CONSTRUCTOR,
+	METHOD,
+	UNKNOWN;
 
 	@Override
 	public String toString() {
