@@ -1,7 +1,10 @@
 package aQute.launcher.agent;
 
-import java.lang.instrument.*;
+import java.lang.instrument.Instrumentation;
 
+import org.osgi.annotation.bundle.Header;
+
+@Header(name = "Premain-Class", value = "${@class}")
 public class LauncherAgent {
 
 	public static Instrumentation	instrumentation;
