@@ -1,14 +1,21 @@
 package aQute.bnd.deployer.http;
 
-import java.net.*;
-import java.security.*;
-import java.security.cert.*;
+import java.net.URLConnection;
+import java.security.GeneralSecurityException;
+import java.security.SecureRandom;
+import java.security.cert.CertificateException;
+import java.security.cert.X509Certificate;
 
-import javax.net.ssl.*;
+import javax.net.ssl.HostnameVerifier;
+import javax.net.ssl.HttpsURLConnection;
+import javax.net.ssl.SSLContext;
+import javax.net.ssl.SSLSocketFactory;
+import javax.net.ssl.TrustManager;
+import javax.net.ssl.X509TrustManager;
 
 public class HttpsUtil {
 
-	public static final String	PROP_DISABLE_SERVER_CERT_VERIFY	= "disableServerVerify";
+	public static final String PROP_DISABLE_SERVER_CERT_VERIFY = "disableServerVerify";
 
 	static void disableServerVerification(URLConnection connection) throws GeneralSecurityException {
 		if (!(connection instanceof HttpsURLConnection))
@@ -17,12 +24,15 @@ public class HttpsUtil {
 		HttpsURLConnection httpsConnection = (HttpsURLConnection) connection;
 		TrustManager[] trustAllCerts = new TrustManager[] {
 			new X509TrustManager() {
+				@Override
 				public X509Certificate[] getAcceptedIssuers() {
 					return null;
 				}
 
+				@Override
 				public void checkServerTrusted(X509Certificate[] certs, String authType) throws CertificateException {}
 
+				@Override
 				public void checkClientTrusted(X509Certificate[] certs, String authType) throws CertificateException {}
 			}
 		};
@@ -33,11 +43,7 @@ public class HttpsUtil {
 		SSLSocketFactory sslSocketFactory = sslContext.getSocketFactory();
 		httpsConnection.setSSLSocketFactory(sslSocketFactory);
 
-		HostnameVerifier trustAnyHost = new HostnameVerifier() {
-			public boolean verify(String string, SSLSession session) {
-				return true;
-			}
-		};
+		HostnameVerifier trustAnyHost = (string, session) -> true;
 		httpsConnection.setHostnameVerifier(trustAnyHost);
 	}
-}
\ No newline at end of file
+}
