@@ -1,87 +1,128 @@
 package aQute.bnd.deployer.repository;
 
-import static aQute.bnd.deployer.repository.RepoResourceUtils.*;
+import static aQute.bnd.deployer.repository.RepoResourceUtils.getContentSha;
+import static aQute.bnd.deployer.repository.RepoResourceUtils.getContentUrl;
+import static aQute.bnd.deployer.repository.RepoResourceUtils.getIdentityCapability;
+import static aQute.bnd.deployer.repository.RepoResourceUtils.readIndex;
 
-import java.io.*;
-import java.net.*;
-import java.util.*;
+import java.io.File;
+import java.io.FileNotFoundException;
+import java.io.InputStream;
+import java.net.MalformedURLException;
+import java.net.URI;
+import java.net.URISyntaxException;
+import java.net.URL;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.Dictionary;
+import java.util.EnumSet;
+import java.util.HashMap;
+import java.util.Hashtable;
+import java.util.LinkedList;
+import java.util.List;
+import java.util.Map;
 import java.util.Map.Entry;
+import java.util.Set;
+import java.util.SortedMap;
+import java.util.SortedSet;
+import java.util.StringTokenizer;
+import java.util.TreeMap;
 
-import org.osgi.impl.bundle.bindex.*;
-import org.osgi.resource.*;
+import org.osgi.framework.namespace.IdentityNamespace;
+import org.osgi.resource.Capability;
+import org.osgi.resource.Requirement;
 import org.osgi.resource.Resource;
-import org.osgi.service.bindex.*;
-import org.osgi.service.log.*;
-import org.osgi.service.repository.*;
+import org.osgi.service.log.LogService;
+import org.osgi.service.repository.ContentNamespace;
+import org.osgi.service.repository.Repository;
 
-import aQute.bnd.deployer.http.*;
-import aQute.bnd.deployer.repository.api.*;
-import aQute.bnd.deployer.repository.providers.*;
-import aQute.bnd.osgi.*;
-import aQute.bnd.service.*;
+import aQute.bnd.deployer.repository.api.IRepositoryContentProvider;
+import aQute.bnd.deployer.repository.api.IRepositoryIndexProcessor;
+import aQute.bnd.deployer.repository.api.Referral;
+import aQute.bnd.deployer.repository.providers.R5RepoContentProvider;
+import aQute.bnd.http.HttpClient;
+import aQute.bnd.osgi.Constants;
+import aQute.bnd.osgi.repository.BaseRepository;
+import aQute.bnd.osgi.resource.CapReqBuilder;
+import aQute.bnd.service.IndexProvider;
+import aQute.bnd.service.Plugin;
+import aQute.bnd.service.Refreshable;
+import aQute.bnd.service.Registry;
+import aQute.bnd.service.RegistryPlugin;
+import aQute.bnd.service.RemoteRepositoryPlugin;
+import aQute.bnd.service.ResolutionPhase;
+import aQute.bnd.service.ResourceHandle;
 import aQute.bnd.service.ResourceHandle.Location;
-import aQute.bnd.service.url.*;
-import aQute.bnd.version.*;
-import aQute.lib.filter.*;
-import aQute.libg.glob.*;
-import aQute.libg.gzip.*;
-import aQute.service.reporter.*;
+import aQute.bnd.service.Strategy;
+import aQute.bnd.service.url.URLConnector;
+import aQute.bnd.version.Version;
+import aQute.bnd.version.VersionRange;
+import aQute.lib.filter.Filter;
+import aQute.lib.io.IO;
+import aQute.lib.strings.Strings;
+import aQute.libg.glob.Glob;
+import aQute.libg.gzip.GZipUtils;
+import aQute.service.reporter.Reporter;
 
 /**
  * Abstract base class for indexed repositories.
  * <p>
  * The repository implementation is read-only by default. To implement a
  * writable repository, subclasses should override {@link #canWrite()} and
- * {@link #put(Jar)}.
- * 
+ * {@link #put(InputStream, aQute.bnd.service.RepositoryPlugin.PutOptions)}.
+ *
  * @author Neil Bartlett
  */
 @SuppressWarnings("synthetic-access")
-public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, RemoteRepositoryPlugin, IndexProvider, Repository, Refreshable {
+public abstract class AbstractIndexedRepo extends BaseRepository
+	implements RegistryPlugin, Plugin, RemoteRepositoryPlugin, IndexProvider, Repository, Refreshable {
 
-	public static final String									PROP_NAME						= "name";
-	public static final String									PROP_REPO_TYPE					= "type";
-	public static final String									PROP_RESOLUTION_PHASE			= "phase";
-	public static final String									PROP_RESOLUTION_PHASE_ANY		= "any";
+	private static final String								SHA_256							= "SHA-256";
 
-	public static final String									REPO_TYPE_R5					= R5RepoContentProvider.NAME;
-	public static final String									REPO_TYPE_OBR					= ObrContentProvider.NAME;
-	public static final String									REPO_INDEX_SHA_EXTENSION		= ".sha";
-	public static final String									PROP_CACHE_TIMEOUT				= "timeout";
-	public static final String									PROP_ONLINE						= "online";
-	
-	private final static int DEFAULT_CACHE_TIMEOUT = 5;
+	public static final String								PROP_NAME						= "name";
+	public static final String								PROP_REPO_TYPE					= "type";
+	public static final String								PROP_RESOLUTION_PHASE			= "phase";
+	public static final String								PROP_RESOLUTION_PHASE_ANY		= "any";
+
+	public static final String								REPO_TYPE_R5					= R5RepoContentProvider.NAME;
+	public static final String								REPO_INDEX_SHA_EXTENSION		= ".sha";
+	public static final String								PROP_CACHE_TIMEOUT				= "timeout";
+	public static final String								PROP_ONLINE						= "online";
+	public static final String								PROP_VERSION_KEY				= "version";
+	public static final String								PROP_VERSION_HASH				= "hash";
+	public static final String								PROP_CHECK_BSN					= "bsn";
+
+	private final static int								DEFAULT_CACHE_TIMEOUT			= 5;
 
-	
-	private final BundleIndexer								obrIndexer						= new BundleIndexerImpl();
-	
 	/**
 	 * Make sure the content providers are always processed in the same order.
 	 */
-	protected final Map<String,IRepositoryContentProvider>	allContentProviders				= new TreeMap<String,IRepositoryContentProvider>();
-	
-	protected final List<IRepositoryContentProvider>		generatingProviders				= new LinkedList<IRepositoryContentProvider>();
+	protected final Map<String, IRepositoryContentProvider>	allContentProviders				= new TreeMap<>();
 
-	protected Registry											registry;
-	protected Reporter											reporter;
-	protected LogService										logService						= new NullLogService();
-	protected String											name							= this.getClass().getName();
-	protected Set<ResolutionPhase>								supportedPhases					= EnumSet.allOf(ResolutionPhase.class);
+	protected final List<IRepositoryContentProvider>		generatingProviders				= new LinkedList<>();
 
-	private List<URI>											indexLocations;
+	protected Registry										registry;
+	protected Reporter										reporter;
+	protected LogService									logService						= new NullLogService();
+	protected String										name							= this.getClass()
+		.getName();
+	protected Set<ResolutionPhase>							supportedPhases					= EnumSet
+		.allOf(ResolutionPhase.class);
 
-	private String												requestedContentProviderList	= null;
+	private List<URI>										indexLocations;
 
-	private boolean												initialised						= false;
+	private String											requestedContentProviderList	= null;
+
+	private boolean											initialised						= false;
 
 	private final CapabilityIndex							capabilityIndex					= new CapabilityIndex();
 	private final VersionedResourceIndex					identityMap						= new VersionedResourceIndex();
-	private int cacheTimeoutSeconds = DEFAULT_CACHE_TIMEOUT;
-	private boolean online = true;
+	private int												cacheTimeoutSeconds				= DEFAULT_CACHE_TIMEOUT;
+	private boolean											online							= true;
 
 	protected AbstractIndexedRepo() {
 		allContentProviders.put(REPO_TYPE_R5, new R5RepoContentProvider());
-		allContentProviders.put(REPO_TYPE_OBR, new ObrContentProvider(obrIndexer));
 
 		generatingProviders.add(allContentProviders.get(REPO_TYPE_R5));
 	}
@@ -120,7 +161,11 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 		}
 	}
 
-	protected final synchronized void init() throws Exception {
+	protected final void init() throws Exception {
+		init(false);
+	}
+
+	protected final synchronized void init(boolean ignoreCachedFile) throws Exception {
 		if (!initialised) {
 			clear();
 
@@ -134,7 +179,8 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 				// Find the requested providers from the available ones.
 				StringTokenizer tokenizer = new StringTokenizer(requestedContentProviderList, "|");
 				while (tokenizer.hasMoreTokens()) {
-					String token = tokenizer.nextToken().trim();
+					String token = tokenizer.nextToken()
+						.trim();
 					IRepositoryContentProvider provider = allContentProviders.get(token);
 					if (provider == null) {
 						warning("Unknown repository content provider \"%s\".", token);
@@ -143,7 +189,8 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 					}
 				}
 				if (generatingProviders.isEmpty()) {
-					warning("No valid repository index generators were found, requested list was: [%s]", requestedContentProviderList);
+					warning("No valid repository index generators were found, requested list was: [%s]",
+						requestedContentProviderList);
 				}
 			}
 
@@ -154,26 +201,31 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 			final URLConnector connector = getConnector();
 			IRepositoryIndexProcessor processor = new IRepositoryIndexProcessor() {
 
+				@Override
 				public void processResource(Resource resource) {
 					identityMap.put(resource);
 					capabilityIndex.addResource(resource);
 				}
 
+				@Override
 				public void processReferral(URI parentUri, Referral referral, int maxDepth, int currentDepth) {
 					try {
 						URI indexLocation = new URI(referral.getUrl());
 						try {
-							CachingUriResourceHandle indexHandle = new CachingUriResourceHandle(indexLocation, getCacheDirectory(), connector, (String) null);
+							CachingUriResourceHandle indexHandle = new CachingUriResourceHandle(indexLocation,
+								getCacheDirectory(), connector, null);
 							indexHandle.setReporter(reporter);
-							readIndex(indexLocation.getPath(), indexLocation, new FileInputStream(indexHandle.request()), allContentProviders.values(), this, logService);
-						}
-						catch (Exception e) {
-							warning("Unable to read referral index at URL '%s' from parent index '%s': %s", indexLocation, parentUri, e);
+							InputStream indexStream = GZipUtils.detectCompression(IO.stream(indexHandle.request()));
+							readIndex(indexLocation.getPath(), indexLocation, indexStream, allContentProviders.values(),
+								this, logService);
+						} catch (Exception e) {
+							warning("Unable to read referral index at URL '%s' from parent index '%s': %s",
+								indexLocation, parentUri, e);
 						}
 
-					}
-					catch (URISyntaxException e) {
-						warning("Invalid referral URL '%s' from parent index '%s': %s", referral.getUrl(), parentUri, e);
+					} catch (URISyntaxException e) {
+						warning("Invalid referral URL '%s' from parent index '%s': %s", referral.getUrl(), parentUri,
+							e);
 					}
 				}
 
@@ -182,12 +234,14 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 			// Parse the indexes
 			for (URI indexLocation : indexLocations) {
 				try {
-					CachingUriResourceHandle indexHandle = new CachingUriResourceHandle(indexLocation, getCacheDirectory(), connector, (String) null);
+					CachingUriResourceHandle indexHandle = new CachingUriResourceHandle(indexLocation,
+						getCacheDirectory(), connector, null);
 					// If there is a cachedFile, then just use it IF
 					// 1) the cachedFile is within the timeout period
 					// OR 2) online is false
-					if (indexHandle.cachedFile != null &&
-							((System.currentTimeMillis() - indexHandle.cachedFile.lastModified() < this.cacheTimeoutSeconds * 1000)
+					if (indexHandle.cachedFile != null && !ignoreCachedFile
+						&& ((System.currentTimeMillis()
+							- indexHandle.cachedFile.lastModified() < this.cacheTimeoutSeconds * 1000)
 							|| !this.online)) {
 						indexHandle.sha = indexHandle.getCachedSHA();
 						if (indexHandle.sha != null && !this.online) {
@@ -196,10 +250,10 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 					}
 					indexHandle.setReporter(reporter);
 					File indexFile = indexHandle.request();
-					InputStream indexStream = GZipUtils.detectCompression(new FileInputStream(indexFile));
-					readIndex(indexFile.getName(), indexLocation, indexStream, allContentProviders.values(), processor, logService);
-				}
-				catch (Exception e) {
+					InputStream indexStream = GZipUtils.detectCompression(IO.stream(indexFile));
+					readIndex(indexFile.getName(), indexLocation, indexStream, allContentProviders.values(), processor,
+						logService);
+				} catch (Exception e) {
 					error("Unable to read index at URL '%s': %s", indexLocation, e);
 				}
 			}
@@ -208,34 +262,31 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 		}
 	}
 
+	@Override
 	public final List<URI> getIndexLocations() throws Exception {
 		init();
 		return Collections.unmodifiableList(indexLocations);
 	}
 
 	/**
-	 * @return the class to use for URL connections. It's retrieved from the
-	 *         registry under the URLConnector class, or it will be the
-	 *         DefaultURLConnector if the former was not found.
+	 * @return the current Http Client
 	 */
 	private URLConnector getConnector() {
-		URLConnector connector;
-		synchronized (this) {
-			connector = registry != null ? registry.getPlugin(URLConnector.class) : null;
+		if (registry != null) {
+			HttpClient plugin = registry.getPlugin(HttpClient.class);
+			if (plugin != null)
+				return plugin;
 		}
-		if (connector == null) {
-			DefaultURLConnector defaultConnector = new DefaultURLConnector();
-			defaultConnector.setRegistry(registry);
-			connector = defaultConnector;
-		}
-		return connector;
+		return new HttpClient();
 	}
 
+	@Override
 	public synchronized final void setRegistry(Registry registry) {
 		this.registry = registry;
 	}
 
-	public synchronized void setProperties(Map<String,String> map) {
+	@Override
+	public synchronized void setProperties(Map<String, String> map) {
 		if (map.containsKey(PROP_NAME))
 			name = map.get(PROP_NAME);
 
@@ -243,25 +294,24 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 			supportedPhases = EnumSet.noneOf(ResolutionPhase.class);
 			StringTokenizer tokenizer = new StringTokenizer(map.get(PROP_RESOLUTION_PHASE), ",");
 			while (tokenizer.hasMoreTokens()) {
-				String token = tokenizer.nextToken().trim();
+				String token = tokenizer.nextToken()
+					.trim();
 				if (PROP_RESOLUTION_PHASE_ANY.equalsIgnoreCase(token))
 					supportedPhases = EnumSet.allOf(ResolutionPhase.class);
 				else {
 					try {
 						supportedPhases.add(ResolutionPhase.valueOf(token));
-					}
-					catch (Exception e) {
+					} catch (Exception e) {
 						error("Unknown OBR resolution mode: " + token);
 					}
 				}
 			}
 		}
-		
+
 		if (map.containsKey(PROP_CACHE_TIMEOUT)) {
 			try {
 				this.cacheTimeoutSeconds = Integer.parseInt(map.get(PROP_CACHE_TIMEOUT));
-			}
-			catch (NumberFormatException e) {
+			} catch (NumberFormatException e) {
 				error("Bad timeout setting. Must be integer number of milliseconds.");
 			}
 		}
@@ -269,7 +319,7 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 		if (map.containsKey(PROP_ONLINE)) {
 			this.online = Boolean.parseBoolean(map.get(PROP_ONLINE));
 		}
-		
+
 		requestedContentProviderList = map.get(PROP_REPO_TYPE);
 	}
 
@@ -279,7 +329,7 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 		return requestAll(handles);
 	}
 
-	protected static File[] requestAll(ResourceHandle[] handles) throws IOException {
+	protected static File[] requestAll(ResourceHandle[] handles) throws Exception {
 		File[] result;
 		if (handles == null)
 			result = new File[0];
@@ -302,72 +352,80 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 		List<Resource> resources = identityMap.getRange(bsn, rangeStr);
 		List<ResourceHandle> handles = mapResourcesToHandles(resources);
 
-		return (ResourceHandle[]) handles.toArray(new ResourceHandle[handles.size()]);
+		return handles.toArray(new ResourceHandle[0]);
 	}
 
+	@Override
 	public synchronized void setReporter(Reporter reporter) {
 		this.reporter = reporter;
 		this.logService = new ReporterLogService(reporter);
 	}
 
-	public File get(String bsn, String range, Strategy strategy, Map<String,String> properties) throws Exception {
+	public File get(String bsn, String range, Strategy strategy, Map<String, String> properties) throws Exception {
 		ResourceHandle handle = getHandle(bsn, range, strategy, properties);
 		return handle != null ? handle.request() : null;
 	}
 
-	public ResourceHandle getHandle(String bsn, String range, Strategy strategy, Map<String,String> properties)
-			throws Exception {
+	@Override
+	public ResourceHandle getHandle(String bsn, String range, Strategy strategy, Map<String, String> properties)
+		throws Exception {
 		init();
 		ResourceHandle result;
 		if (bsn != null)
-			result = resolveBundle(bsn, range, strategy);
+			result = resolveBundle(bsn, range, strategy, properties);
 		else {
 			throw new IllegalArgumentException("Cannot resolve bundle: bundle symbolic name not specified.");
 		}
 		return result;
 	}
 
+	@Override
 	public boolean canWrite() {
 		return false;
 	}
 
+	@Override
 	public PutResult put(InputStream stream, PutOptions options) throws Exception {
 		throw new UnsupportedOperationException("Read-only repository.");
 	}
 
+	@Override
 	public List<String> list(String pattern) throws Exception {
 		init();
 		Glob glob = pattern != null ? new Glob(pattern) : null;
-		List<String> result = new LinkedList<String>();
+		List<String> result = new LinkedList<>();
 
 		for (String bsn : identityMap.getIdentities()) {
-			if (glob == null || glob.matcher(bsn).matches())
+			if (glob == null || glob.matcher(bsn)
+				.matches())
 				result.add(bsn);
 		}
 
 		return result;
 	}
 
+	@Override
 	public SortedSet<Version> versions(String bsn) throws Exception {
 		init();
 		return identityMap.getVersions(bsn);
 	}
 
+	@Override
 	public synchronized String getName() {
 		return name;
 	}
-	
-	public Map<Requirement,Collection<Capability>> findProviders(Collection< ? extends Requirement> requirements) {
+
+	@Override
+	public Map<Requirement, Collection<Capability>> findProviders(Collection<? extends Requirement> requirements) {
 		try {
 			init();
-		}
-		catch (Exception e) {
+		} catch (Exception e) {
 			throw new RuntimeException(e);
 		}
-		
-		Map<Requirement,Collection<Capability>> result = new HashMap<Requirement,Collection<Capability>>();
+
+		Map<Requirement, Collection<Capability>> result = new HashMap<>();
 		for (Requirement requirement : requirements) {
-			List<Capability> matches = new LinkedList<Capability>();
+			List<Capability> matches = new LinkedList<>();
 			result.put(requirement, matches);
 
 			capabilityIndex.appendMatchingCapabilities(requirement, matches);
@@ -375,14 +433,16 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 		return result;
 	}
 
-	static List<Resource> narrowVersionsByFilter(String pkgName, SortedMap<Version,Resource> versionMap, Filter filter) {
-		List<Resource> result = new ArrayList<Resource>(versionMap.size());
+	static List<Resource> narrowVersionsByFilter(String pkgName, SortedMap<Version, Resource> versionMap, Filter filter)
+		throws Exception {
+		List<Resource> result = new ArrayList<>(versionMap.size());
 
-		Dictionary<String,String> dict = new Hashtable<String,String>();
+		Dictionary<String, String> dict = new Hashtable<>();
 		dict.put("package", pkgName);
 
-		for (Entry<Version,Resource> entry : versionMap.entrySet()) {
-			dict.put("version", entry.getKey().toString());
+		for (Entry<Version, Resource> entry : versionMap.entrySet()) {
+			dict.put("version", entry.getKey()
+				.toString());
 			if (filter.match(dict))
 				result.add(entry.getValue());
 		}
@@ -391,7 +451,7 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 	}
 
 	List<ResourceHandle> mapResourcesToHandles(Collection<Resource> resources) throws Exception {
-		List<ResourceHandle> result = new ArrayList<ResourceHandle>(resources.size());
+		List<ResourceHandle> result = new ArrayList<>(resources.size());
 
 		for (Resource resource : resources) {
 			ResourceHandle handle = mapResourceToHandle(resource);
@@ -408,13 +468,13 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 		CachingUriResourceHandle handle;
 		try {
 			String contentSha = getContentSha(resource);
-			handle = new CachingUriResourceHandle(getContentUrl(resource), getCacheDirectory(), getConnector(), contentSha);
+			handle = new CachingUriResourceHandle(getContentUrl(resource), getCacheDirectory(), getConnector(),
+				contentSha);
 			if (contentSha == null) {
 				handle.sha = handle.getCachedSHA();
 			}
-		}
-		catch (FileNotFoundException e) {
-			throw new FileNotFoundException("Broken link in repository index: " + e.getMessage());
+		} catch (FileNotFoundException e) {
+			throw new FileNotFoundException("Broken link in repository index: " + e);
 		}
 		if (handle.getLocation() == Location.local || getCacheDirectory() != null)
 			result = handle;
@@ -422,10 +482,15 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 		return result;
 	}
 
-	ResourceHandle resolveBundle(String bsn, String rangeStr, Strategy strategy) throws Exception {
+	ResourceHandle resolveBundle(String bsn, String rangeStr, Strategy strategy, Map<String, String> properties)
+		throws Exception {
 		if (rangeStr == null)
 			rangeStr = "0.0.0";
 
+		if (PROP_VERSION_HASH.equals(rangeStr)) {
+			return findByHash(bsn, properties);
+		}
+
 		if (strategy == Strategy.EXACT) {
 			return findExactMatch(bsn, rangeStr);
 		}
@@ -446,7 +511,7 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 		return selected;
 	}
 
-	static String listToString(List< ? > list) {
+	static String listToString(List<?> list) {
 		StringBuilder builder = new StringBuilder();
 
 		int count = 0;
@@ -469,25 +534,72 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 		return mapResourceToHandle(resource);
 	}
 
+	ResourceHandle findByHash(String bsn, Map<String, String> properties) throws Exception {
+		if (bsn == null)
+			throw new IllegalArgumentException("Bundle symbolic name must be specified");
+
+		// Get the hash string
+		String hashStr = properties.get("hash");
+		if (hashStr == null)
+			throw new IllegalArgumentException(
+				"Content hash must be provided (using hash=<algo>:<hash>) when version=hash is specified");
+
+		// Parse into algo and hash
+		String algo = SHA_256;
+		int colonIndex = hashStr.indexOf(':');
+		if (colonIndex > -1) {
+			algo = hashStr.substring(0, colonIndex);
+			int afterColon = colonIndex + 1;
+			hashStr = (colonIndex < hashStr.length()) ? hashStr.substring(afterColon) : "";
+		}
+
+		// R5 indexes are always SHA-256
+		if (!SHA_256.equalsIgnoreCase(algo))
+			return null;
+
+		String contentFilter = String.format("(%s=%s)", ContentNamespace.CONTENT_NAMESPACE, hashStr);
+		Requirement contentReq = new CapReqBuilder(ContentNamespace.CONTENT_NAMESPACE).filter(contentFilter)
+			.buildSyntheticRequirement();
+
+		List<Capability> caps = new LinkedList<>();
+		capabilityIndex.appendMatchingCapabilities(contentReq, caps);
+
+		if (caps.isEmpty())
+			return null;
+
+		Resource resource = caps.get(0)
+			.getResource();
+
+		Capability identityCap = getIdentityCapability(resource);
+		Object id = identityCap.getAttributes()
+			.get(IdentityNamespace.IDENTITY_NAMESPACE);
+		if (!bsn.equals(id))
+			throw new IllegalArgumentException(
+				String.format("Resource with requested hash does not match ID '%s' [hash: %s]", bsn, hashStr));
+
+		return mapResourceToHandle(resource);
+	}
+
 	/**
 	 * Utility function for parsing lists of URLs.
-	 * 
-	 * @param locationsStr
-	 *            Comma-separated list of URLs
+	 *
+	 * @param locationsStr Comma-separated list of URLs
 	 * @return a list of URIs
 	 * @throws MalformedURLException
 	 * @throws URISyntaxException
 	 */
 	protected static List<URI> parseLocations(String locationsStr) throws MalformedURLException, URISyntaxException {
 		StringTokenizer tok = new StringTokenizer(locationsStr, ",");
-		List<URI> urls = new ArrayList<URI>(tok.countTokens());
+		List<URI> urls = new ArrayList<>(tok.countTokens());
 		while (tok.hasMoreTokens()) {
-			String urlStr = tok.nextToken().trim();
+			String urlStr = tok.nextToken()
+				.trim();
 			urls.add(new URL(urlStr).toURI());
 		}
 		return urls;
 	}
 
+	@Override
 	public Set<ResolutionPhase> getSupportedPhases() {
 		return supportedPhases;
 	}
@@ -500,12 +612,19 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 	/**
 	 * This can be optimized to use the download technique with the listeners.
 	 * Now just a quick hack to make it work. I actually think these classes
-	 * should extend FileRepo. TODO 
+	 * should extend FileRepo. TODO
 	 */
-	public File get(String bsn, Version version, Map<String,String> properties, DownloadListener... listeners)
-			throws Exception {
+	@Override
+	public File get(String bsn, Version version, Map<String, String> properties, DownloadListener... listeners)
+		throws Exception {
 		init();
-		ResourceHandle handle = resolveBundle(bsn, version.toString(), Strategy.EXACT);
+
+		String versionStr;
+		if (version != null)
+			versionStr = version.toString();
+		else
+			versionStr = properties.get(PROP_VERSION_KEY);
+		ResourceHandle handle = resolveBundle(bsn, versionStr, Strategy.EXACT, properties);
 		if (handle == null)
 			return null;
 
@@ -516,48 +635,31 @@ public abstract class AbstractIndexedRepo implements RegistryPlugin, Plugin, Rem
 		for (DownloadListener l : listeners) {
 			try {
 				l.success(f);
-			}
-			catch (Exception e) {
+			} catch (Exception e) {
 				error("Download listener for %s: %s", f, e);
 			}
 		}
 		return f;
 	}
-	
+
 	private void error(String format, Object... args) {
 		if (reporter != null)
 			reporter.error(format, args);
 		else
-			System.err.println(String.format(format, args));
+			System.err.println(Strings.format(format, args));
 	}
 
 	private void warning(String format, Object... args) {
 		if (reporter != null)
 			reporter.warning(format, args);
 		else
-			System.err.println(String.format(format, args));
+			System.err.println(Strings.format(format, args));
 	}
 
+	@Override
 	public boolean refresh() throws Exception {
-		boolean ret = true;
-		if (indexLocations != null) {
-			final URLConnector connector = getConnector();
-			for (URI indexLocation : indexLocations) {
-				CachingUriResourceHandle indexHandle;
-				try {
-					File f = new CachingUriResourceHandle(indexLocation, getCacheDirectory(), connector, (String) null).cachedFile;
-					if (f != null && f.exists() && !f.delete()) {
-						error("Unable to delete cached repository index file %s", f.getAbsolutePath());
-					}
-				}
-				catch (IOException e) {
-					error("Exception during refresh of %s", indexLocation, e);
-					ret = false;
-				}
-			}
-		}
 		initialised = false;
-		init();
-		return ret;
+		init(true);
+		return true;
 	}
 }
